args_match

Function args_match 

fn args_match<'hir>(
    hir: &'hir Hir<'hir>,
    args: &CallArgs<'hir>,
    params: &[VariableId],
) -> bool
Returns true if args can target params by arity and (when inferable) by type at each position. Arguments whose type cannot be inferred do not reject a candidate.