fn args_match<'hir>(
hir: &'hir Hir<'hir>,
args: &CallArgs<'hir>,
params: &[VariableId],
) -> boolExpand description
Returns true if args can target params by arity and (when inferable) by type at each
position. Arguments whose type cannot be inferred do not reject a candidate.